@@ -2,8 +2,7 @@
 Collection of utitly functions for file I/O operations. The purpose is
 especially for scientific computing, thus numpy is involved in some functions.
 Copyright (C) 2022 Julian M. Kleber This program comes with ABSOLUTELY NO
-WARRANTY; for details type 'show w'. This is free software, and you are welcome
-to redistribute it under certain conditions; type 'show c' for details.".
+WARRANTY."
 
 author: Julian M. Kleber
 """
